import { describe, it, expect, vi, beforeEach, afterEach } from "vitest";

describe("Environment Configuration", () => {
  const originalEnv = process.env;

  beforeEach(() => {
    vi.resetModules();
    process.env = { ...originalEnv };
  });

  afterEach(() => {
    process.env = originalEnv;
  });

  it("should set NODE_ENV to development by default", async () => {
    delete process.env.NODE_ENV;
    const { envs, isProduction } = await import("./index");
    expect(envs.NODE_ENV).toBe("development");
    expect(isProduction).toBe(false);
  });

  it("should use existing NODE_ENV if set", async () => {
    process.env.NODE_ENV = "production";
    const { envs, isProduction } = await import("./index");
    expect(envs.NODE_ENV).toBe("production");
    expect(isProduction).toBe(true);
  });

  it("should export config from dotenv-flow", async () => {
    const { config } = await import("./index");
    expect(config).toBeDefined();
  });
});
