import { IndexController } from "./IndexController";
import { describe, it, expect, beforeEach } from "vitest";

describe("IndexController", () => {
  let controller: IndexController;

  beforeEach(() => {
    controller = new IndexController();
    // @ts-expect-error - swagger is private
    controller.swagger = [
      { path: "/api-docs", specVersion: "3.0.1" },
      { path: "/api-docs-2", specVersion: "3.0.2" }
    ];
  });

  it("should return correct view data", () => {
    const protocol = "https";
    const host = "example.com";

    const result = controller.get(protocol, host);

    expect(result).toEqual({
      BASE_URL: "https://example.com",
      docs: [
        { url: "https://example.com/api-docs", path: "/api-docs", specVersion: "3.0.1" },
        { url: "https://example.com/api-docs-2", path: "/api-docs-2", specVersion: "3.0.2" }
      ]
    });
  });

  it("should use http when protocol is not provided", () => {
    const host = "example.com";

    const result = controller.get("", host);

    expect(result.BASE_URL).toBe("http://example.com");
  });
});
