import { PathParams } from "@tsed/platform-params";
import { Description, Get, Post, Returns, Summary } from "@tsed/schema";
import { Controller, Inject } from "@tsed/di";
import { User } from "../../entities/User";
import { SqliteDatasource } from "../../datasources/SqliteDatasource";
import { DataSource } from "typeorm";
import { executeWithRetry } from "../../datasources/SqliteDatasource";
import { Forbidden } from "@tsed/exceptions";

@Controller("/users")
export class UserController {
  constructor(@Inject(SqliteDatasource) private sqliteDataSource: DataSource) {}

  // disable the create method and endpoint
  @Post("/")
  @Summary("Create a new user")
  @Description("This endpoint can not be used. Users are created automatically when a new link is created.")
  @Returns(403)
  async create(): Promise<void> {
    throw new Forbidden("Users are created automatically when a new link is created.");
  }

  @Get("/")
  @Summary("Get all users")
  @(Returns(200, Array).Of(User))
  async getList(): Promise<User[]> {
    return executeWithRetry(async (queryRunner) => {
      return queryRunner.manager.find(User);
    }, this.sqliteDataSource);
  }

  @Get("/:id")
  @Summary("Get a user by ID")
  @Returns(200, User)
  async getOne(@PathParams("id") id: string): Promise<User | null> {
    return executeWithRetry(async (queryRunner) => {
      return queryRunner.manager.findOne(User, {
        where: {
          id
        }
      });
    }, this.sqliteDataSource);
  }
}
