import { MaxLength, Property, Required } from "@tsed/schema";
import { Column, Entity, ManyToOne, PrimaryColumn, JoinColumn, BeforeInsert } from "typeorm";
import { User } from "../User";
import { v4 as uuidv4 } from "uuid";

@Entity()
export class Link {
  @PrimaryColumn("uuid")
  @Property()
  id: string;

  @Column({ length: 100 })
  @MaxLength(100)
  @Required()
  service: string;

  @Column({ length: 100 })
  @MaxLength(100)
  @Required()
  serviceUsername: string;

  @ManyToOne(() => User, (user) => user.links, { onDelete: "SET NULL", onUpdate: "CASCADE" })
  @JoinColumn({ name: "userId" })
  user: User;

  @Column({ type: "uuid", nullable: true })
  @Property()
  userId: string | null;

  @BeforeInsert()
  generateId() {
    if (!this.id) {
      this.id = uuidv4();
    }
  }
}
